@@ -30,7 +30,7 @@ namespace OneD {
 class Code93Reader : public RowReader
 {
 public:
-	Result decodePattern(int rowNumber, const PatternView& row, std::unique_ptr<DecodingState>&) const override;
+	Result decodePattern(int rowNumber, PatternView& next, std::unique_ptr<DecodingState>&) const override;
 };
 
 } // OneD
