@@ -2,6 +2,7 @@
 /*
 * Copyright 2016 Nu-book Inc.
 * Copyright 2016 ZXing authors
+* Copyright 2021 Axel Waggershauser
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -16,6 +17,10 @@
 * limitations under the License.
 */
 
+#include "ConcentricFinder.h"
+
+#include <vector>
+
 namespace ZXing {
 
 class DetectorResult;
@@ -23,25 +28,20 @@ class BitMatrix;
 
 namespace QRCode {
 
-/**
-* <p>Encapsulates logic that can detect a QR Code in an image, even if the QR Code
-* is rotated or skewed, or partially obscured.</p>
-*
-* @author Sean Owen
-*/
-class Detector
+struct FinderPatternSet
 {
-public:
-	/**
-	* <p>Detects a QR Code in an image.</p>
-	*
-	* @param hints optional hints to detector
-	* @return {@link DetectorResult} encapsulating results of detecting a QR Code
-	* @throws NotFoundException if QR Code cannot be found
-	* @throws FormatException if a QR Code cannot be decoded
-	*/
-	static DetectorResult Detect(const BitMatrix& image, bool pureBarcode, bool tryHarder);
+	ConcentricPattern bl, tl, tr;
 };
 
+using FinderPatternSets = std::vector<FinderPatternSet>;
+
+FinderPatternSets FindFinderPatternSets(const BitMatrix& image, bool tryHarder);
+DetectorResult SampleAtFinderPatternSet(const BitMatrix& image, const FinderPatternSet& fp);
+
+/**
+ * @brief Detects a QR Code in an image.
+ */
+DetectorResult Detect(const BitMatrix& image, bool tryHarder, bool isPure);
+
 } // QRCode
 } // ZXing
